@@ -20,8 +20,6 @@
 #' @param err_eff Type I error rate: Efficacious but toxic
 #' @param err_tox Type I error rate: Safe but futile
 #' @param err_all Type I error rate: Futile and toxic
-#' @param power_eff power: Efficacious but toxic
-#' @param power_tox power: Safe but futile
 #' @param power_all power: Futile and toxic
 #' @param nSwarm nSwarm in PSO
 #' @param maxIter maxIter in PSO
@@ -49,8 +47,6 @@
 #' # err_eff = 1,  
 #' # err_tox = 1 , 
 #' # err_all = 0.1,  
-#' # power_eff = 0.8,
-#' # power_tox = 0.8,
 #' # power_all = 0.8,
 #' # nParallel = 3,
 #' # seed = 5321,
@@ -70,7 +66,7 @@
 #'
 #' 
 #' @export
-#' @import globpso R6 RcppArmadillo 
+#' @import globpso R6 
 #' @importFrom stats dbinom na.omit pbeta pgamma rmultinom runif
 #' @importFrom dplyr filter select distinct
 #' @importFrom foreach %dopar% foreach %do%
@@ -97,8 +93,6 @@ GBOP2_maxP_TE <- function(design = "optimal",
                           err_eff = 1,  # Type I error rate: Efficacious but toxic
                           err_tox = 1 , # Type I error rate: Safe but futile
                           err_all = 0.1,  # Type I error rate: Futile and toxic
-                          power_eff = 0.8,
-                          power_tox = 0.8,
                           power_all = 0.8,
                           nParallel = 3,
                           seed = 5321,
@@ -127,8 +121,7 @@ GBOP2_maxP_TE <- function(design = "optimal",
                            e1n = e1n, e2n = e2n, e3n = e3n, e1a = e1a, e2a = e2a,  e3a = e3a, # Ha for Eff and Tox
                            err_eff = err_eff,  # Type I error rate: Efficacious but toxic
                            err_tox = err_tox,  err_all = err_all,  # Type I error rate: Futile and toxic
-                           power_eff = power_eff,
-                           power_tox = power_tox, power_all = power_all, seed = seed, nSwarm = nSwarm,maxIter = 1
+                            power_all = power_all, seed = seed, nSwarm = nSwarm,maxIter = 1
   )
   
   end_time <- Sys.time()  # End timing
@@ -220,8 +213,7 @@ GBOP2_maxP_TE <- function(design = "optimal",
                   e1n = e1n, e2n = e2n, e3n = e3n, e1a = e1a, e2a = e2a,  e3a = e3a, # Ha for Eff and Tox
                   err_eff = err_eff,  # Type I error rate: Efficacious but toxic
                   err_tox = err_tox,  err_all = err_all,  # Type I error rate: Futile and toxic
-                  power_eff = power_eff,
-                  power_tox = power_tox, power_all = power_all, seed = seed, nSwarm = nSwarm,maxIter = maxIter
+                   power_all = power_all, seed = seed, nSwarm = nSwarm,maxIter = maxIter
      )
 
 
@@ -232,8 +224,7 @@ GBOP2_maxP_TE <- function(design = "optimal",
                                          e1n = e1n, e2n = e2n, e3n = e3n, e1a = e1a, e2a = e2a,  e3a = e3a, # Ha for Eff and Tox
                                         err_eff = err_eff,  # Type I error rate: Efficacious but toxic
                                          err_tox = err_tox,  err_all = err_all,  # Type I error rate: Futile and toxic
-                                         power_eff = power_eff,
-                                         power_tox = power_tox, power_all = power_all, seed = current_seed, nSwarm = nSwarm,maxIter = maxIter
+                                          power_all = power_all, seed = current_seed, nSwarm = nSwarm,maxIter = maxIter
                      )
 
                      r3 <- PSO_power_TE(method = "dexp",nlooks = nlooks,
@@ -242,8 +233,7 @@ GBOP2_maxP_TE <- function(design = "optimal",
                                         e1n = e1n, e2n = e2n, e3n = e3n, e1a = e1a, e2a = e2a,  e3a = e3a, # Ha for Eff and Tox
                                         err_eff = err_eff,  # Type I error rate: Efficacious but toxic
                                         err_tox = err_tox,  err_all = err_all,  # Type I error rate: Futile and toxic
-                                        power_eff = power_eff,
-                                        power_tox = power_tox, power_all = power_all, seed = current_seed, nSwarm = nSwarm,maxIter = maxIter
+                                         power_all = power_all, seed = current_seed, nSwarm = nSwarm,maxIter = maxIter
                      )
 
                      # Combine the results and select best
@@ -279,7 +269,7 @@ GBOP2_maxP_TE <- function(design = "optimal",
                        filter(Utility == min(Utility)) |>
                        filter(Power == max(Power))
                      
-                     r_ensemble[[1]] <- "GBOP2_minSS_TE"
+                     r_ensemble[[1]] <- "GBOP2_maxP_TE"
                      results <- r_ensemble
                      return(results)
                  } 
@@ -308,8 +298,6 @@ GBOP2_maxP_TE <- function(design = "optimal",
                                        err_eff = err_eff,  # Type I error rate: Efficacious but toxic
                                        err_tox = err_tox , # Type I error rate: Safe but futile
                                        err_all = err_all,  # Type I error rate: Futile and toxic
-                                       power_eff = power_eff,
-                                       power_tox = power_tox,
                                        power_all = power_all,
                                        seed = seed,
                                        nSwarm = nSwarm,
