@@ -20,8 +20,6 @@
 #' @param err_eff Type I error rate: Efficacious but toxic
 #' @param err_tox Type I error rate: Safe but futile
 #' @param err_all Type I error rate: Futile and toxic
-#' @param power_eff power: Efficacious but toxic
-#' @param power_tox power: Safe but futile
 #' @param power_all power: Futile and toxic
 #' @param pso_method "all" for using three distinct pso, otherwise indicate single pso method
 #' @param nSwarm nSwarm in PSO
@@ -50,8 +48,6 @@
 #' #    err_eff = 0.1, 
 #' #    err_tox = 0.1, 
 #' #    err_all = 0.05, 
-#' #    power_eff = 0.8, 
-#' #    power_tox = 0.8, 
 #' #    power_all = 0.8, 
 #' #    pso_method = "default", 
 #' #    nParallel = 3, 
@@ -71,7 +67,7 @@
 #' are planned, consider using `init_cluster(nCore)` and `stop_cluster()` manually to control the backend.
 #'  
 #' @export
-#' @import globpso R6 RcppArmadillo 
+#' @import globpso R6 
 #' @importFrom stats dbinom na.omit pbeta pgamma rmultinom runif
 #' @importFrom dplyr filter select distinct
 #' @importFrom foreach %dopar% foreach %do%
@@ -98,8 +94,6 @@ GBOP2_minSS_TE <- function(design = "optimal", ## choose from "optimal", "minima
                             err_eff = 0.1, ## Type I error for futile
                             err_tox = 0.1, ## Type I error for toxic
                             err_all = 0.05, ## Type I futile and toxic,
-                            power_eff = 0.8, ## power for futile
-                            power_tox = 0.8, ## power for toxic
                             power_all = 0.8, ## power for futile and toxic
                             pso_method = "all", ## choose from "all", ""default", "quantum" or "dexp"
                             nParallel = 3, ## number of PSO_ensemble
@@ -125,8 +119,7 @@ GBOP2_minSS_TE <- function(design = "optimal", ## choose from "optimal", "minima
   one_task <- PSO_design_TE(design = design, unified.u = unified.u, method = "default", nlooks = nlooks, skip_efficacy = skip_efficacy,
                             skip_toxicity = skip_toxicity, maxPatients = maxPatients, Nmin_cohort1 = Nmin_cohort1,
                             Nmin_increase = Nmin_increase, e1n = e1n, e2n = e2n, e3n = e3n, e1a = e1a, e2a = e2a,
-                            e3a = e3a, err_eff = err_eff, err_tox = err_tox, err_all = err_all, power_eff = power_eff,
-                            power_tox = power_tox, power_all = power_all, seed = seed,nSwarm = nSwarm, maxIter = 1)
+                            e3a = e3a, err_eff = err_eff, err_tox = err_tox, err_all = err_all,  power_all = power_all, seed = seed,nSwarm = nSwarm, maxIter = 1)
   
   end_time <- Sys.time()  # End timing
   execution_time1T <- as.numeric(end_time - start_time)  # Convert to numeric (seconds)
@@ -196,20 +189,17 @@ GBOP2_minSS_TE <- function(design = "optimal", ## choose from "optimal", "minima
                      r1 <- PSO_design_TE(design = design, unified.u = unified.u, method = "default", nlooks = nlooks, skip_efficacy = skip_efficacy,
                                         skip_toxicity = skip_toxicity, maxPatients = maxPatients, Nmin_cohort1 = Nmin_cohort1,
                                         Nmin_increase = Nmin_increase, e1n = e1n, e2n = e2n, e3n = e3n, e1a = e1a, e2a = e2a,
-                                        e3a = e3a, err_eff = err_eff, err_tox = err_tox, err_all = err_all, power_eff = power_eff,
-                                        power_tox = power_tox, power_all = power_all, seed = current_seed, nSwarm = nSwarm, maxIter = maxIter)
+                                        e3a = e3a, err_eff = err_eff, err_tox = err_tox, err_all = err_all,  power_all = power_all, seed = current_seed, nSwarm = nSwarm, maxIter = maxIter)
 
                      r2 <- PSO_design_TE(design = design, unified.u = unified.u, method = "quantum", nlooks = nlooks, skip_efficacy = skip_efficacy,
                                         skip_toxicity = skip_toxicity, maxPatients = maxPatients, Nmin_cohort1 = Nmin_cohort1,
                                         Nmin_increase = Nmin_increase, e1n = e1n, e2n = e2n, e3n = e3n, e1a = e1a, e2a = e2a,
-                                        e3a = e3a, err_eff = err_eff, err_tox = err_tox, err_all = err_all, power_eff = power_eff,
-                                        power_tox = power_tox, power_all = power_all, seed = current_seed, nSwarm = nSwarm, maxIter = maxIter)
+                                        e3a = e3a, err_eff = err_eff, err_tox = err_tox, err_all = err_all,  power_all = power_all, seed = current_seed, nSwarm = nSwarm, maxIter = maxIter)
 
                      r3 <- PSO_design_TE(design = design, unified.u = unified.u, method = "dexp", nlooks = nlooks, skip_efficacy = skip_efficacy,
                                         skip_toxicity = skip_toxicity, maxPatients = maxPatients, Nmin_cohort1 = Nmin_cohort1,
                                         Nmin_increase = Nmin_increase, e1n = e1n, e2n = e2n, e3n = e3n, e1a = e1a, e2a = e2a,
-                                        e3a = e3a, err_eff = err_eff, err_tox = err_tox, err_all = err_all, power_eff = power_eff,
-                                        power_tox = power_tox, power_all = power_all, seed = current_seed, nSwarm = nSwarm, maxIter = maxIter)
+                                        e3a = e3a, err_eff = err_eff, err_tox = err_tox, err_all = err_all,  power_all = power_all, seed = current_seed, nSwarm = nSwarm, maxIter = maxIter)
 
                      # Combine the results and select best
                      r1 <- unclass(r1)
@@ -260,8 +250,7 @@ GBOP2_minSS_TE <- function(design = "optimal", ## choose from "optimal", "minima
                      r <- PSO_design_TE(design = design, unified.u = unified.u, method = pso_method, nlooks = nlooks, skip_efficacy = skip_efficacy,
                                        skip_toxicity = skip_toxicity, maxPatients = maxPatients, Nmin_cohort1 = Nmin_cohort1,
                                        Nmin_increase = Nmin_increase, e1n = e1n, e2n = e2n, e3n = e3n, e1a = e1a, e2a = e2a,
-                                       e3a = e3a, err_eff = err_eff, err_tox = err_tox, err_all = err_all, power_eff = power_eff,
-                                       power_tox = power_tox, power_all = power_all, nSwarm = nSwarm, maxIter = maxIter)
+                                       e3a = e3a, err_eff = err_eff, err_tox = err_tox, err_all = err_all,  power_all = power_all, nSwarm = nSwarm, maxIter = maxIter)
 
     
                      res_final <- r
