@@ -18,8 +18,6 @@ PSO_design_TE <- function(design = "optimal",
                          err_eff = 0.1,  # Type I error rate: Efficacious but toxic
                          err_tox = 0.1,  # Type I error rate: Safe but futile
                          err_all = 0.05,  # Type I error rate: Futile and toxic
-                         power_eff = 0.8,
-                         power_tox = 0.8,
                          power_all = 0.8,
                          seed = 1024,
                          nSwarm = 32,
@@ -70,8 +68,6 @@ if((!is.null(skip_efficacy) && (length(skip_efficacy) != (nlooks +1) ) )| (!is.n
     err_eff = err_eff,  # Type I error rate: Efficacious but toxic
     err_tox = err_tox,  # Type I error rate: Safe but futile
     err_all = err_all,  # Type I error rate: Futile and toxic
-    power_eff = power_eff,
-    power_tox = power_tox,
     power_all = power_all,
     seed = seed
   )
