@@ -14,8 +14,6 @@ PSO_power_TE <- function(method = "default",
                          err_eff = 1,  # Type I error rate: Efficacious but toxic
                          err_tox = 1 , # Type I error rate: Safe but futile
                          err_all = 0.1,  # Type I error rate: Futile and toxic
-                         power_eff = 0.8,
-                         power_tox = 0.8,
                          power_all = 0.8,
                          seed = 1024,
                          nSwarm = 32,
@@ -67,8 +65,6 @@ PSO_power_TE <- function(method = "default",
     err_eff = err_eff,  # Type I error rate: Efficacious but toxic
     err_tox = err_tox,  # Type I error rate: Safe but futile
     err_all = err_all,  # Type I error rate: Futile and toxic
-    power_eff = power_eff,
-    power_tox = power_tox,
     power_all = power_all,
     seed = seed
   )
@@ -333,8 +329,10 @@ PSO_power_TE <- function(method = "default",
   # upp_bound <- c(0.99, 0.99, 1, 0.99, 0.99, pi/2, pi/2, pi/2)
   
   if(nlooks ==1){
-    low_bound <- c(0.5, 0.5, 0, 0.5, 0, 0.5)
-    upp_bound <- c(0.99, 0.99, 1,  0.99, 1, 0.99)
+    # low_bound <- c(0.5, 0.5, 0, 0.5, 0, 0.5)
+    # upp_bound <- c(0.99, 0.99, 1,  0.99, 1, 0.99)
+    low_bound <- c(0.5, 0.5, 0, 0, 0.5, 0.5)  # Note: 4th element is 0
+    upp_bound <- c(0.99, 0.99, 1, 1, 0.99, 0.99)  # Note: 4th element is 1
   } else{
     theta_L <- rep(0, nlooks) ## lower bound of theta
     theta_U <- rep(pi/2, nlooks) ## upper bound of theta
