@@ -59,7 +59,7 @@ summary.gbop2 <- function(object, ...) {
     cat("design:           ", design, "\n")
     cat("weight:           ", weight, "\n")
     cat("method:           ", method, "\n")
-    cat("CPU Time:         ", format(cputime, digits = 4), " seconds\n\n")
+    
 
     cat("parameters:\n")
     cat("  lambda1:        ", format(parameter$lambda1, digits = 6), "\n")
@@ -99,7 +99,7 @@ summary.gbop2 <- function(object, ...) {
 
     cat("design:           ", design, "\n")
     cat("method:           ", method, "\n")
-    cat("CPU Time:         ", format(cputime, digits = 4), " seconds\n\n")
+    
 
     cat("parameters:\n")
     cat("  lambda1:        ", format(lambda1, digits = 6), "\n")
@@ -143,7 +143,7 @@ summary.gbop2 <- function(object, ...) {
     cat("design:           ", design, "\n")
     cat("weight:           ", weight, "\n")
     cat("method:           ", method, "\n")
-    cat("cpu time:         ", format(cputime, digits = 4), " seconds\n\n")
+    
 
     cat("parameters:\n")
     cat("  lambda1:        ", format(lambda1, digits = 6), "\n")
@@ -184,7 +184,7 @@ summary.gbop2 <- function(object, ...) {
     cat("PSOGO for maximizing power with single boundary\n")
     cat("design:           ", design, "\n")
     cat("method:           ", method, "\n")
-    cat("cpu time:         ", format(cputime, digits = 4), " seconds\n\n")
+    
 
     cat("parameters:\n")
     cat("  lambda1:        ", format(lambda1, digits = 6), "\n")
