@@ -1,10 +1,12 @@
+#define R_NO_REMAP
+#define ARMA_DONT_USE_WRAPPER
 #include <cmath>
 #include <algorithm>
 #include <vector>
 #include <limits>
 #include <RcppArmadillo.h>
-#include <math.h>
 #include <Rmath.h>
+
 using namespace Rcpp;
 
 //#include <RcppEigen.h>
