@@ -1,9 +1,10 @@
+#define R_NO_REMAP
+#define ARMA_DONT_USE_WRAPPER
 #include <cmath>
 #include <algorithm>
 #include <vector>
 #include <limits>
 #include <RcppArmadillo.h>
-#include <math.h>
 #include <Rmath.h>
 #include "GBOP2_types.h"
 
@@ -17,12 +18,20 @@ using namespace std;
 
 
 
+// set seed (old version - commented out)
+// void set_seed(unsigned int seed) {
+//   Rcpp::Environment base_env("package:base");
+//   Rcpp::Function set_seed_r = base_env["set.seed"];
+//   set_seed_r(seed);
+// }
+
 // set seed
 // [[Rcpp::export]]
 void set_seed(unsigned int seed) {
-  Rcpp::Environment base_env("package:base");
-  Rcpp::Function set_seed_r = base_env["set.seed"];
-  set_seed_r(seed);
+  SEXP seed_val = Rf_protect(Rf_ScalarInteger(seed));
+  SEXP call = Rf_protect(Rf_lang2(Rf_install("set.seed"), seed_val));
+  Rf_eval(call, R_GlobalEnv);
+  Rf_unprotect(2);
 }
 
 double dbinom_product( const NumericVector & vXs,  NumericVector & nobs, double prob);
@@ -203,7 +212,7 @@ Result_singleE exact_error_recursive2(Rcpp::NumericVector nobs, Rcpp::NumericVec
     Data nonstopping_df_null;
     std::vector<double> probabilities_null;
     for (int i = ncut[0] + 1; i <= nobs[0]; i++) {
-      probabilities_null.push_back(R::dbinom(i, nobs[0], pnull, false));
+      probabilities_null.push_back(Rf_dbinom(i, nobs[0], pnull, false));
     }
     nonstopping_df_null.prob = probabilities_null;
     std::vector<int> mySet_null;
@@ -216,7 +225,7 @@ Result_singleE exact_error_recursive2(Rcpp::NumericVector nobs, Rcpp::NumericVec
     Data stopping_df_null;
     std::vector<double> probabilities_null2;
     for (int i = 0; i <= ncut[0]; i++) {
-      probabilities_null2.push_back(R::dbinom(i, nobs[0], pnull, false));
+      probabilities_null2.push_back(Rf_dbinom(i, nobs[0], pnull, false));
     }
     stopping_df_null.prob = probabilities_null2;
     std::vector<int> mySet_null2;
@@ -276,7 +285,7 @@ Result_singleE exact_error_recursive2(Rcpp::NumericVector nobs, Rcpp::NumericVec
       for (std::size_t j = 0; j < newevent.size(); j++){
         
         int new_event_value = nonstop_null.num_event[i] + newevent[j];
-        double dbinom_result = R::dbinom(newevent[j], nobs_diff, pnull, false);
+        double dbinom_result = Rf_dbinom(newevent[j], nobs_diff, pnull, false);
         
         newdf.num_event.push_back(new_event_value);
         newdf.prob.push_back(prob * dbinom_result);
@@ -337,7 +346,7 @@ Result_singleE exact_error_recursive2(Rcpp::NumericVector nobs, Rcpp::NumericVec
       for (std::size_t j = 0; j < newevent.size(); j++){
         
         int new_event_value = nonstop_null.num_event[i] + newevent[j];
-        double dbinom_result = R::dbinom(newevent[j], nobs_diff, pnull, false);
+        double dbinom_result = Rf_dbinom(newevent[j], nobs_diff, pnull, false);
         
         newdf.num_event.push_back(new_event_value);
         newdf.prob.push_back(prob * dbinom_result);
@@ -390,7 +399,8 @@ double my_dbinom(double x, double size, double prob) {
   if (x < 0 || x > size) {
     return 0;
   }
-  return R::choose(size, x) * std::pow(prob, x) * std::pow(1 - prob, size - x);
+  //return R::choose(size, x) * std::pow(prob, x) * std::pow(1 - prob, size - x);
+  return Rf_choose(size, x) * std::pow(prob, x) * std::pow(1 - prob, size - x);
 }
 
 // [[Rcpp::export]]
@@ -425,7 +435,6 @@ double dbinom_product(  const NumericVector & vXs,  NumericVector & nobs, double
 
 
 //Binary Efficacy
-// [[Rcpp::depends(RcppEigen)]]
 // [[Rcpp::export]]
 List GetocBiRcpp(int seed, double nsim, NumericMatrix contrast, NumericVector nobs, double b, double b2, double pow2,
                  NumericVector dprior, double ptrue, double phi, Function fff)
@@ -501,7 +510,6 @@ List GetocBiRcpp(int seed, double nsim, NumericMatrix contrast, NumericVector no
 }
 
 
-// [[Rcpp::depends(RcppEigen)]]
 // [[Rcpp::export]]
 NumericMatrix GridSearchBiRcpp(int seed, NumericMatrix contrast, NumericVector nobs, NumericVector dprior,
                                NumericVector b1, NumericVector b2, NumericVector pow, double pn, double pa,
