@@ -1,9 +1,10 @@
+#define R_NO_REMAP
+#define ARMA_DONT_USE_WRAPPER
 #include <cmath>
 #include <algorithm>
 #include <vector>
 #include <limits>
 #include <RcppArmadillo.h>
-#include <math.h>
 #include <Rmath.h>
 #include "GBOP2_types.h"
 
@@ -14,16 +15,23 @@ using namespace Rcpp;
 //using namespace Eigen;
 using namespace std;
 
+// set seed (old version - commented out)
+// void set_seed_dual(unsigned int seed) {
+//   Rcpp::Environment base_env("package:base");
+//   Rcpp::Function set_seed_r = base_env["set.seed"];
+//   set_seed_r(seed);
+// }
+
 // set seed
 // [[Rcpp::export]]
 void set_seed_dual(unsigned int seed) {
-  Rcpp::Environment base_env("package:base");
-  Rcpp::Function set_seed_r = base_env["set.seed"];
-  set_seed_r(seed);
+  SEXP seed_val = Rf_protect(Rf_ScalarInteger(seed));
+  SEXP call = Rf_protect(Rf_lang2(Rf_install("set.seed"), seed_val));
+  Rf_eval(call, R_GlobalEnv);
+  Rf_unprotect(2);
 }
 
 
-
 // // Define a struct to hold data
 // struct Data {
 //   std::vector<int> num_event;
@@ -61,7 +69,7 @@ Result_dualE exacterror_recursive(Rcpp::NumericVector nobs, Rcpp::NumericVector
     std::vector<double> effective_prob_vec;
     for (int i = ncut2[0]; i < nobs[0] + 1; i++) {
       effective_df.num_event.push_back(i);
-      effective_prob_vec.push_back(R::dbinom(i, nobs[0], test_prob, false));
+      effective_prob_vec.push_back(Rf_dbinom(i, nobs[0], test_prob, 0));
     }
     effective_df.prob = effective_prob_vec;
 
@@ -69,7 +77,7 @@ Result_dualE exacterror_recursive(Rcpp::NumericVector nobs, Rcpp::NumericVector
     std::vector<double> nonstop_prob_vec;
     for (int i = ncut1[0] + 1; i < ncut2[0]; i++) {
       nonstop_df.num_event.push_back(i);
-      nonstop_prob_vec.push_back(R::dbinom(i, nobs[0], test_prob, false));
+      nonstop_prob_vec.push_back(Rf_dbinom(i, nobs[0], test_prob, 0));
     }
     nonstop_df.prob = nonstop_prob_vec;
 
@@ -77,7 +85,7 @@ Result_dualE exacterror_recursive(Rcpp::NumericVector nobs, Rcpp::NumericVector
     std::vector<double> futile_prob_vec;
     for (int i = 0; i < ncut1[0] + 1; i++) {
       futile_df.num_event.push_back(i);
-      futile_prob_vec.push_back(R::dbinom(i, nobs[0], test_prob, false));
+      futile_prob_vec.push_back(Rf_dbinom(i, nobs[0], test_prob, 0));
     }
     futile_df.prob = futile_prob_vec;
 
@@ -109,9 +117,12 @@ Result_dualE exacterror_recursive(Rcpp::NumericVector nobs, Rcpp::NumericVector
     res_list.expected_size = ptsa;
     res_list.stopping_prob = stopping_prob;
     res_list.nonstopping_prob = nonstopping_prob;
-    res_list.prob_size_futile = wrap(prob_sizes_futile);
-    res_list.prob_size_effective = wrap(prob_sizes_effective);
-    res_list.prob_size_nonstop = wrap(prob_sizes_nonstop);
+    // res_list.prob_size_futile = wrap(prob_sizes_futile);
+    // res_list.prob_size_effective = wrap(prob_sizes_effective);
+    // res_list.prob_size_nonstop = wrap(prob_sizes_nonstop);
+    res_list.prob_size_futile = prob_sizes_futile;
+    res_list.prob_size_effective = prob_sizes_effective;
+    res_list.prob_size_nonstop = prob_sizes_nonstop;
 
     return res_list;
   } else {
@@ -126,9 +137,12 @@ Result_dualE exacterror_recursive(Rcpp::NumericVector nobs, Rcpp::NumericVector
     ptsa = res_before.expected_size;
     stopping_prob = res_before.stopping_prob;
     nonstopping_prob = res_before.nonstopping_prob;
-    NumericVector prob_sizes_futile = res_before.prob_size_futile;
-    NumericVector prob_sizes_effective = res_before.prob_size_effective;
-    NumericVector prob_sizes_nonstop = res_before.prob_size_nonstop;
+    // NumericVector prob_sizes_futile = res_before.prob_size_futile;
+    // NumericVector prob_sizes_effective = res_before.prob_size_effective;
+    // NumericVector prob_sizes_nonstop = res_before.prob_size_nonstop;
+    std::vector<double> prob_sizes_futile = res_before.prob_size_futile;
+    std::vector<double> prob_sizes_effective = res_before.prob_size_effective;
+    std::vector<double> prob_sizes_nonstop = res_before.prob_size_nonstop;
 
     Data effective_df_new;
     for (int i = 0; i < nonstop_df.num_event.size(); i++) {
@@ -156,7 +170,7 @@ Result_dualE exacterror_recursive(Rcpp::NumericVector nobs, Rcpp::NumericVector
       Data newdf;
       for (int k = 0; k < newevent.size(); k++) {
         int new_event_value = nonstop_df.num_event[i] + newevent[k];
-        double dbinom_result = R::dbinom(newevent[k], nobs[n_c - 1] - nobs[n_c - 2], test_prob, false);
+        double dbinom_result = Rf_dbinom(newevent[k], nobs[n_c - 1] - nobs[n_c - 2], test_prob, 0);
 
         newdf.num_event.push_back(new_event_value);
         newdf.prob.push_back(prob * dbinom_result);
@@ -192,7 +206,7 @@ Result_dualE exacterror_recursive(Rcpp::NumericVector nobs, Rcpp::NumericVector
       Data newdf;
       for (int k = 0; k < newevent.size(); k++) {
         int new_event_value = nonstop_df.num_event[i] + newevent[k];
-        double dbinom_result = R::dbinom(newevent[k], nobs[n_c - 1] - nobs[n_c - 2], test_prob, false);
+        double dbinom_result = Rf_dbinom(newevent[k], nobs[n_c - 1] - nobs[n_c - 2], test_prob, 0);
 
         newdf.num_event.push_back(new_event_value);
         newdf.prob.push_back(prob * dbinom_result);
@@ -249,7 +263,7 @@ Result_dualE exacterror_recursive(Rcpp::NumericVector nobs, Rcpp::NumericVector
       Data newdf;
       for (int k = 0; k < newevent.size(); k++) {
         int new_event_value = nonstop_df.num_event[i] + newevent[k];
-        double dbinom_result = R::dbinom(newevent[k], nobs[n_c - 1] - nobs[n_c - 2], test_prob, false);
+        double dbinom_result = Rf_dbinom(newevent[k], nobs[n_c - 1] - nobs[n_c - 2], test_prob, 0);
 
         newdf.num_event.push_back(new_event_value);
         newdf.prob.push_back(prob * dbinom_result);
@@ -294,9 +308,12 @@ Result_dualE exacterror_recursive(Rcpp::NumericVector nobs, Rcpp::NumericVector
     res_list.expected_size = ptsa;
     res_list.stopping_prob = stopping_prob;
     res_list.nonstopping_prob = nonstopping_prob;
-    res_list.prob_size_futile = wrap(prob_sizes_futile);
-    res_list.prob_size_effective = wrap(prob_sizes_effective);
-    res_list.prob_size_nonstop = wrap(prob_sizes_nonstop);
+    // res_list.prob_size_futile = wrap(prob_sizes_futile);
+    // res_list.prob_size_effective = wrap(prob_sizes_effective);
+    // res_list.prob_size_nonstop = wrap(prob_sizes_nonstop);
+    res_list.prob_size_futile = prob_sizes_futile;
+    res_list.prob_size_effective = prob_sizes_effective;
+    res_list.prob_size_nonstop = prob_sizes_nonstop;
 
     return res_list;
   }
@@ -355,7 +372,6 @@ List exact_error_recursive_Rcpp(Rcpp::NumericVector nobs, Rcpp::NumericVector nc
 
 
 //Binary Efficacy
-// [[Rcpp::depends(RcppEigen)]]
 // [[Rcpp::export]]
 List GetocBiRcpp_dual(int seed, double nsim, NumericMatrix contrast, NumericVector nobs, double b,
                       double b_grad1, double b_grad2, double pow1, double pow2, double pow3,
